/*
 * Copyright (C) Sergey P. Derevyago, 2005.
 *
 * Permission to copy, use, modify, sell and distribute this software is granted
 * provided this copyright notice appears in all copies.
 * This software is provided "as is" without express or implied warranty, and
 * with no claim as to its suitability for any purpose.
 *
 */

package ders;

/**
 * Cannot encrypt <code>ders.Exception</code>.
 *
 * Meaning: This particular data cannot be encrypted using this particular key.
 * Cause: The hashes of the both decrypted blocks (with original and changed
 *        most significant remainder) collide. So the decryption process would
 *        not be able to determine which one is right.
 * Advice: Modify the plain text you want to encrypt (add some insignificant
 *         spaces or so). Robust systems would probably add some additional byte
 *         to their data format to be changed in case of CannotEncryptException.
 */
public final class CannotEncryptException extends Exception
{
 CannotEncryptException()
 {
 }

 /**
  * Returns explanatory error message.
  */
 public String getMessage()
 {
  return "Cannot encrypt this data using this key: Hash collision";
 }
}

