/*
 * Copyright (C) Sergey P. Derevyago, 2005.
 *
 * Permission to copy, use, modify, sell and distribute this software is granted
 * provided this copyright notice appears in all copies.
 * This software is provided "as is" without express or implied warranty, and
 * with no claim as to its suitability for any purpose.
 *
 */

package ders;

import java.io.PrintStream;

/**
 * The base class of all exceptions thrown by DersCrypt cipher. Special
 * subclasses are used for every possible exception.
 */
public class Exception extends java.lang.Exception
{
 Exception()
 {
  super((String)null);
 }

 Exception(Throwable thr)
 {
  this();
  linkedThrowable=thr;
 }

 /**
  * Returns some general error message for testing purposes. This method is
  * always overridden by special subclasses.
  */
 public String getMessage()
 {
  return "General derscrypt.Exception";
 }

 /**
  * Returns the cause of this exception or <code>null</code> if the cause is
  * non-existent or unknown.
  */
 public final Throwable getLinkedThrowable()
 {
  return linkedThrowable;
 }

 /**
  * Prints stack trace for this exception and all the linked throwables.
  *
  * @param ps stream to use
  */
 public void printStackTraceAll(PrintStream ps)
 {
  for (Throwable t=this; t!=null; ) {
      t.printStackTrace(ps);

      if (t instanceof Exception) t=((Exception)t).getLinkedThrowable();
      else break;
  }
 }
 
 private Throwable linkedThrowable;
}

