/*
 * Copyright (C) Sergey P. Derevyago, 2005.
 *
 * Permission to copy, use, modify, sell and distribute this software is granted
 * provided this copyright notice appears in all copies.
 * This software is provided "as is" without express or implied warranty, and
 * with no claim as to its suitability for any purpose.
 *
 */

package ders;

/**
 * Excessive data <code>ders.InvalidDataException</code>.
 *
 * Meaning: Excessive data is tried to be encrypted.
 * Cause: The data block passed to <code>blockEncrypt()</code> or
 *        <code>blockDecrypt()</code> method is too long for the key being used.
 * Advice: Smaller data block must be used. You can check the length with
 *         <code>maxBlockLength()</code> method. 
 */
public final class ExcessiveDataException extends InvalidDataException
{
 ExcessiveDataException(int maxLen)
 {
  maxDataLenght=maxLen;
 }

 /**
  * Returns maximum allowed data block length.
  */
 public int getMaxDataLenght()
 {
  return maxDataLenght;
 }

 /**
  * Returns explanatory error message.
  */
 public String getMessage()
 {
  return "Excessive data length: No more than "+maxDataLenght+" bytes are "+
    "required";
 }

 private int maxDataLenght;
}

