/*
 * Copyright (C) Sergey P. Derevyago, 2005.
 *
 * Permission to copy, use, modify, sell and distribute this software is granted
 * provided this copyright notice appears in all copies.
 * This software is provided "as is" without express or implied warranty, and
 * with no claim as to its suitability for any purpose.
 *
 */

package ders;

/**
 * Incorrect key <code>ders.Exception</code>.
 *
 * Meaning: Wrong key is used to decrypt the data.
 * Cause: The hash that was computed from the plain data is not equal to the
 *        hash computed from the decrypted data. 
 * Advice: Make sure that the correct key is used to decrypt the data. Make sure
 *         that the key and/or data were not modified after the encryption.
 */
public final class IncorrectKeyException extends Exception
{
 IncorrectKeyException()
 {
 }

 /**
  * Returns explanatory error message.
  */
 public String getMessage()
 {
  return "Incorrect key and/or data: Hash mismatch";
 }
}

