/*
 * Copyright (C) Sergey P. Derevyago, 2005.
 *
 * Permission to copy, use, modify, sell and distribute this software is granted
 * provided this copyright notice appears in all copies.
 * This software is provided "as is" without express or implied warranty, and
 * with no claim as to its suitability for any purpose.
 *
 */

package ders;

/**
 * Insufficient data <code>ders.InvalidDataException</code>.
 *
 * Meaning: Insufficient data is tried to be encrypted.
 * Cause: The data block passed to an encryption method is too short for the key
 *        being used.
 * Advice: Bigger data block must be used (enlarge your data using some
 *         insignificant bytes). You can check the length with
 *         <code>minBlockLength()</code> method.
 */
public final class InsufficientDataException extends InvalidDataException
{
 InsufficientDataException(int minLen)
 {
  minDataLenght=minLen;
 }

 /**
  * Returns minimum allowed data block length.
  */
 public int getMinDataLenght()
 {
  return minDataLenght;
 }

 /**
  * Returns explanatory error message.
  */
 public String getMessage()
 {
  return "Insufficient data length: At least "+minDataLenght+" bytes are "+
    "required";
 }
 
 private int minDataLenght;
}

