/*
 * Copyright (C) Sergey P. Derevyago, 2005.
 *
 * Permission to copy, use, modify, sell and distribute this software is granted
 * provided this copyright notice appears in all copies.
 * This software is provided "as is" without express or implied warranty, and
 * with no claim as to its suitability for any purpose.
 *
 */

package ders;

import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.RandomAccessFile;

/**
 * Provides command line UI to DersCrypt cipher.  
 */
public final class Main
{
 /**
  * The main function.
  * Checks passed parameters and performs requested operation.
  */
 public static void main(String[] args)
 {
  Exception exc=null;
  try {
      System.out.println(
        "DersCrypt v1.1 (2005-12-24), symmetric-key block cipher, freeware\n"+
        "Copyright (C) Sergey P. Derevyago\n"
      );

      if (args.length!=4) invalidArgs();

      String sCmd=args[0];
      String sKey=args[1];
      String sIn=args[2];
      String sOut=args[3];

      if ( !("e".equals(sCmd) || "d".equals(sCmd)) ) invalidArgs();

      Key key=new Key(readFile(sKey));

      FileInputStream fin=new FileInputStream(sIn);
      try {
          FileOutputStream fout=new FileOutputStream(sOut);
          try {
              long start=System.currentTimeMillis();

              long cnt= ("e".equals(sCmd)) ?
                Crypt.streamEncrypt(key, fin, fout) :
                Crypt.streamDecrypt(key, fin, fout);

              long dsec=(System.currentTimeMillis()-start+50)/100;
              if (dsec!=0)
                 System.out.println((dsec/10)+" sec, "+(cnt*10/dsec)+" b/s");
          }
          finally { fout.close(); }
      }
      finally { fin.close(); }
  }
  catch (Exception e) { exc=e; }
  catch (Throwable t) { exc=new Exception(t); }

  if (exc!=null) {
     System.err.println("Error occured!");
     exc.printStackTraceAll(System.err);
  }
 }

 private static void invalidArgs()
 {
  System.err.println("Invalid args. Must be:");
  System.err.println("e|d key_file input_file output_file");
  System.exit(1);
 }
 
 private static byte[] readFile(String name) throws Exception
 {
  try {
      RandomAccessFile raf=new RandomAccessFile(name, "r");
      try {
          byte[] ret=new byte[(int)raf.length()];
          raf.readFully(ret);
          
          return ret;
      }
      finally { raf.close(); }
  }
  catch (Throwable t) { throw new Exception(t); }
 }
}

